#
# spec file for package python-importlib-resources
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-importlib-resources
Version:        6.5.2
Release:        1.1
Summary:        Read resources from Python packages
License:        Apache-2.0
URL:            https://importlib-resources.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/i/importlib_resources/importlib_resources-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module jaraco.test >= 5.4}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 6}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module zipp >= 3.1.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-importlib_resources = %{version}
Obsoletes:      python-importlib_resources < %{version}
BuildArch:      noarch
%if 0%{python_version_nodots} < 310
Requires:       python-zipp >= 3.1.0
%endif
%python_subpackages

%description
importlib_resources is a library which provides for access to resources in
Python packages. It provides functionality similar to pkg_resources Basic
Resource Access API, but without all of the overhead and performance problems
of pkg_resources.

In our terminology, a resource is a file tree that is located alongside an
importable Python module. Resources can live on the file system or in a zip
file, with support for other loader classes that implement the appropriate API
for reading resources.

importlib_resources supplies a backport of importlib.resources, enabling early
access to features of future Python versions and making functionality available
for older Python versions. Users are encouraged to use the Python standard
library where suitable and fall back to this library for future compatibility.
Developers looking for detailed API descriptions should refer to the standard
library documentation.

%prep
%setup -q -n importlib_resources-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/importlib_resources
%{python_sitelib}/importlib_resources-%{version}.dist-info

%changelog
* Tue Apr  8 2025 Ben Greiner <code@bnavigator.de>
- Update to 6.5.2
  * Replaced reference to typing_extensions with stdlib Literal.
    (#323)
- Previous releases since 6.1.1
  * Updated Traversable.read_text() to reflect the errors parameter
    (python/cpython#127012). (#321)
  * Add type annotations for Traversable.open. (#317)
  * Require Python 3.9 or later.
  * Omit sentinel values from a namespace path. (#311)
  * When inferring the caller in files() correctly detect one’s own
    module even when the resources package source is not present.
    (gh#python/cpython#123085)
  * Merged fix for UTF-16 BOM handling in functional tests. (#312)
  * When constructing ZipReader, only append the name if the
    indicated module is a package. (python/cpython#121735)
  * The functions is_resource(), open_binary(), open_text(),
    path(), read_binary(), and read_text() are un-deprecated, and
    support subdirectories via multiple positional arguments. The
    contents() function also allows subdirectories, but remains
    deprecated. (#303)
  * Deferred select imports in for a speedup
    (python/cpython#109829).
  * Restored expectation that local standard readers are preferred
    over degenerate readers. (#298)
  * Restored expectation that stdlib readers are suppressed on
    Python 3.10. (#257)
  * Add Anchor to importlib.resources (in order for the code to
    comply with the documentation)
  * Future compatibility adapters now ensure that standard library
    readers are replaced without overriding non-standard readers.
    (#295)
  * Fixed NotADirectoryError when calling files on a subdirectory
    of a namespace package. (#293)
* Tue Mar 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Explicitly BuildRequires zipp, it is now used by the testsuite, and
  was pulled in anyway.
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 6.1.1:
  * Added missed stream argument in simple.ResourceHandle. Ref
    python/cpython#111775.
  * MultiplexedPath now expects Traversable paths. String
    arguments to MultiplexedPath are now deprecated.
  * Enabled support for resources in namespace packages in zip
    files. (#287)
* Tue Aug  8 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.1:
  * Bugfixes
  * Restored Apache license. (#285)
  * Deprecations and Removals
  * Removed legacy functions deprecated in 5.3. (#80)
  * Features
  * Require Python 3.8 or later
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 5.12.0:
  * importlib_resources (backport) now gives
    precedence to built-in readers (file system, zip,
    namespace packages), providing forward-compatibility
    of behaviors like ``MultiplexedPath``.
  * #280: Fixed one more ``EncodingWarning`` in test suite.
  * #265: ``MultiplexedPath`` now honors multiple subdirectories
    in ``iterdir`` and ``joinpath``.
  * Packaging refresh, including fixing EncodingWarnings
    and some tests cleanup.
* Thu Feb  2 2023 Ben Greiner <code@bnavigator.de>
- Remove obsolete cache compilation for tests
  * fixes d:l:p:backports 15.4_py39 build failure.
- Avoid building for not supported Python <= 3.6
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 5.10.2:
  * Prefer ``write_bytes`` to context manager as
  proposed in gh-100586.
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v5.10.1
  * v5.10.1
  [#274]: Fixed ResourceWarning in _common.
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v5.10.0
  * #203: Lifted restriction on modules passed to files. Now modules need not be a package and if a non-package module is passed,
    resources will be resolved adjacent to those modules, even for modules not found in any package. For example,
    files(import_module('mod.py')) will resolve resources found at the root. The parameter to files was renamed from 'package' to 'anchor',
    with a compatibility shim for those passing by keyword.
  * #259: files no longer requires the anchor to be specified and can infer the anchor from the caller's scope (defaults to the caller's module).
* Tue Sep 13 2022 Matej Cepl <mcepl@suse.com>
- Update to 5.9.0:
  - #228: as_file now also supports a Traversable representing
    a directory and (when needed) renders the full tree to a
    temporary directory.
  - #253: In MultiplexedPath, restore expectation that a compound
    path with a non-existent directory does not raise an
    exception.
  - #250: Now Traversable.joinpath provides a concrete
    implementation, replacing the implementation in .simple and
    converging with the behavior in MultiplexedPath.
  - #249: In simple.ResourceContainer.joinpath, honor names split
    by posixpath.sep.
  - #248: abc.Traversable.joinpath now allows for multiple
    arguments and specifies that posixpath.sep is allowed
    in any argument to accept multiple arguments, matching
    the behavior found in zipfile.Path and pathlib.Path
    simple.ResourceContainer now honors this behavior
  - #244: Add type declarations in ABCs Require Python 3.7 or
    later
  - #243: Fix error when no __pycache__ directories exist when
    testing update-zips.
- Remove BR on python-zipp to break a dependency cycle; it is
  strictly not needed for build (although it is Requires),
  because ZipReader is not tested.
* Sat Nov  6 2021 Dirk Müller <dmueller@suse.com>
- update to 5.4.0:
  * Test suite now relies entirely on the traversable API.
  * Now raise a ``DeprecationWarning`` for all legacy
    functions. Instead, users should rely on the ``files()``
    API introduced in importlib_resources 1.3. See
  * Updated readme to reflect current behavior and show
    which versions correspond to which behavior in CPython.
* Mon Sep 20 2021 Ben Greiner <code@bnavigator.de>
- Update to v5.2.2
  * #234: Fix refleak in as_file caught by CPython tests.
- Release v5.2.1
  * bpo-38291: Avoid DeprecationWarning on typing.io.
- Release v5.2.0
  * #80 via #221: Legacy API (path, contents, ...) is now
    supported entirely by the .files() API with a compatibility
    shim supplied for resource loaders without that functionality.
- Release v5.0.6
  * bpo-38693: Prefer f-strings to .format calls.
- Release v5.1.4
  * #225: Require zipp 3.1.0 or later on Python prior to 3.10 to
    incorporate those fixes.
- Release v5.0.5
  * #216: Make MultiplexedPath.name a property per the spec.
- Release v5.1.3
  * Refresh packaging and improve tests.
  * #216: Make MultiplexedPath.name a property per the spec.
- Release v5.1.2
  * Re-release with changes from 5.0.4.
- Release v5.0.4
  * Fixed non-hermetic test in test_reader, revealed by GH-24670.
- Release v5.1.1
  * Re-release with changes from 5.0.3.
- Release v5.0.3
  * Simplified DegenerateFiles.Path.
- Release v5.0.2
  * #214: Added _adapters module to ensure that degenerate files
    behavior can be made available for legacy loaders whose
    resource readers don't implement it. Fixes issue where
    backport compatibility module was masking this fallback
    behavior only to discover the defect when applying changes to
    CPython.
- Release v5.1.0
  * Added simple module implementing adapters from a low-level
    resource reader interface to a TraversableResources interface.
    Closes #90.
- Release v5.0.1
  * Remove pyinstaller hook for hidden 'trees' module.
- Release v5.0.0
  * Removed importlib_resources.trees, deprecated since 1.3.0.
- Release v4.1.1
  * Fixed badges in README.
- Release v4.1.0
  * #209: Adopt jaraco/skeleton.
  * Cleaned up some straggling Python 2 compatibility code.
  * Refreshed test zip files without .pyc and .pyo files.
- Release v4.0.0
  * #108: Drop support for Python 2.7. Now requires Python 3.6+.
- Release v3.3.1
  * Minor cleanup.
* Tue Nov 24 2020 Markéta Machová <mmachova@suse.com>
- Add Obsoletes: line to avoid conflicts with python-importlib_resources
* Fri Nov 20 2020 Benjamin Greiner <code@bnavigator.de>
- Reintroduce into Tumbleweed for python36 flavor
- Update to 3.2.0
  * #68: Resources in PEP 420 Namespace packages are now supported.
- v3.1.1
  * bpo-41490: contents is now also more aggressive about consuming
    any iterator from the Reader.
- v3.1.0
  * #110 and bpo-41490: path method is more aggressive about
    releasing handles to zipfile objects early, enabling use-cases
    like certifi to leave the context open but delete the
    underlying zip file.
- v3.0.0
  * Package no longer exposes importlib_resources.__version__.
    Users that wish to inspect the version of importlib_resources
    should instead invoke .version('importlib_resources') from
    importlib-metadata ( stdlib or backport) directly. This change
    eliminates the dependency on importlib_metadata. Closes #100.
  * Package now always includes its data. Closes #93.
  * Declare hidden imports for PyInstaller. Closes #101.
- v2.0.1
  * Select pathlib and contextlib imports based on Python version
    and avoid pulling in deprecated [pathlib](https://pypi.org/
    project/pathlib). Closes #97.
- v2.0.0
  * Loaders are no longer expected to implement the
    abc.TraversableResources interface, but are instead expected to
    return TraversableResources from their get_resource_reader
    method.
- v1.5.0
  * Traversable is now a Protocol instead of an Abstract Base Class
    (Python 2.7 and Python 3.8+).
  * Traversable objects now require a .name property.
- v1.4.0
  * #79: Temporary files created will now reflect the filename of
    their origin.
- v1.3.1
  * For improved compatibility, importlib_resources.trees is now
    imported implicitly. Closes #88.
- v1.3.0
  * Add extensibility support for non-standard loaders to supply
    Traversable resources. Introduces a new abstract base class
    abc.TraversableResources that supersedes (but implements for
    compatibility) abc.ResourceReader. Any loader that implements
    (implicitly or explicitly) the TraversableResources.files
    method will be capable of supplying resources with subdirectory
    support. Closes #77.
  * Preferred way to access as_file is now from top-level module.
    importlib_resources.trees.as_file is deprecated and
    discouraged. Closes #86.
  * Moved Traversable abc to abc module. Closes #87.
- v1.2.0
  * Traversable now requires an open method. Closes #81.
  * Fixed error on Python 3.5.{0,3}. Closes #83.
  * Updated packaging to resolve version from package metadata.
    Closes #82.
* Tue Aug 25 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add missing runtime dependencies bsc#1175707
* Sat Jun 13 2020 Matej Cepl <mcepl@suse.com>
- Update to 1.1.0 (jsc#PM-1954 bsc#1172933):
  - Add support for retrieving resources from subdirectories of
    packages through the new files() function, which returns
    a Traversable object with joinpath and read_* interfaces
    matching those of pathlib.Path objects. This new function
    supersedes all of the previous functionality as it provides
    a more general-purpose access to a package’s resources.
  - With this function, subdirectories are supported.
  - The documentation has been updated to reflect that this
    function is now the preferred interface for loading package
    resources. It does not, however, support resources from
    arbitrary loaders. It currently only supports resources from
    file system path and zipfile packages (a consequence of the
    ResourceReader interface only operating on Python packages).
* Wed Jul 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- This package is by default provided in python 3.7 and newer
* Thu Mar 21 2019 John Vandenberg <jayvdb@gmail.com>
- Simplify logic for typing dependency
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Jan 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by importlib-metadata
